@@ -22,7 +22,8 @@ class Class:
         super(OtherClass, self).test() # [bad-super-call]
 
 
-# +1: [too-many-arguments,too-many-return-statements, too-many-branches]
+# +1: [line-too-long]
+# +1: [too-many-arguments, too-many-positional-arguments, too-many-return-statements, too-many-branches]
 async def complex_function(this, function, has, more, arguments, than,
                            one, _, should, have):
     if 1:
@@ -39,6 +40,8 @@ async def complex_function(this, function, has, more, arguments, than,
         return than
     try:
         return one
+    except TypeError:
+        pass
     finally:
         pass
     if 2:
